@@ -10,18 +10,23 @@
 #'        the same length as the default parameters of the specification.
 #'        It is the starting value for the chain (if empty the
 #'        the method automatically set starting parameters; see *Details*).
-#'        \item \code{n.burn} (integer >= 0): Number of discarded draws.
-#'        (Default: \code{n.burn = 5000L})
-#'        \item \code{n.mcmc} (integer > 0): Number of draws.
-#'        (Default: \code{n.mcmc = 10000L})
-#'        \item \code{n.thin} (integer > 0): Thinning factor (every \code{N.thin}
-#'        draws are kept). (Default: \code{n.thin = 10L})
+#'        \item \code{nburn} (integer >= 0): Number of discarded draws.
+#'        (Default: \code{nburn = 5000L})
+#'        \item \code{nmcmc} (integer > 0): Number of draws.
+#'        (Default: \code{nmcmc = 10000L})
+#'        \item \code{nthin} (integer > 0): Thinning factor (every \code{nthin}
+#'        draws are kept). (Default: \code{nthin = 10L})
+#'        \item \code{do.sort} (bool): Logical indicating if the MCMC draws are post-sorted
+#'         following Geweke (2007). By default,  \code{do.sort = TRUE}, such that the
+#'         MCMC draws are ordered to ensure that unconditional variance is an 
+#'         increasing function of the regime (identification constraint). If the user sets
+#'          \code{do.sort = FALSE}, no sorting is imposed, and label switching can occur (see *Details*).
 #'        \item \code{SamplerFUN}: Custom MCMC sampler (see *Details*).
 #'        }
 #' @return A list of class \code{MSGARCH_MCMC_FIT} with the following elements:
 #' \itemize{
 #' \item \code{par}: The MCMC chain (matrix from the \R package
-#' \code{coda} (Plummer et al., 2006) of size \code{N.mcmc} / \code{N.thin} x d).
+#' \code{coda} (Plummer et al., 2006) of size \code{nmcmc} / \code{nthin} x d).
 #' \item \code{accept}: Acceptation rate of the sampler.
 #' \item \code{spec}:  Model specification of class \code{MSGARCH_SPEC}
 #' created with \code{\link{CreateSpec}}.
@@ -30,21 +35,19 @@
 #' }
 #' The \code{MSGARCH_MCMC_FIT} with the following methods:
 #' \itemize{
-#' \item \code{\link{AIC}}: Compute Akaike information criterion (AIC).
-#' \item \code{\link{BIC}}: Compute Bayesian information criterion (BIC).
 #' \item \code{\link{DIC}}: Compute Deviance Information Criterion (DIC).
 #' \item \code{\link{Volatility}}: In-sample conditional volatility filterting of the overall process.
-#' \item \code{\link{Forecast}}: Forecast of the conditional volatility of the overall process.
+#' \item \code{predict}: Forecast of the conditional volatility of the overall process.
 #' \item \code{\link{UncVol}}: Unconditional volatility in each regime and the overall process.
-#' \item \code{\link{Pred}}: Predictive method.
+#' \item \code{\link{PredPdf}}: Predictive method.
 #' \item \code{\link{PIT}}: Probability integral transform.
 #' \item \code{\link{Risk}}: Value-at-Risk And Expected-Shortfall methods.
-#' \item \code{\link{Sim}}: Simulation method.
+#' \item \code{simulate}: Simulation method.
 #' \item \code{\link{State}}: State probabilities methods.
 #' \item \code{\link{ExtractStateFit}}: Single-regime model extractor.
 #' \item \code{summary}: Summary of the fit.
 #' }
-#' @details The total number of draws is equal to \code{n.mcmc / n.thin}.
+#' @details The total number of draws is equal to \code{nmcmc / nthin}.
 #' The MCMC/Bayesian estimation relies on an \pkg{Rcpp} implementation of the adaptive sampler of Vihola (2012). 
 #' The implementation is based on the R package \pkg{adaptMCMC} (Andreas, 2012).
 #' Starting values when \code{par0} is not provided are chosen automatically
@@ -57,12 +60,16 @@
 #' parameters. The inputs \code{spec} and \code{data},
 #' must be passed as inputs in the sampler (see *Examples*).
 #' The custom sampler must output a matrix containing the MCMC chain. \cr
+#' When \code{do.sort = TRUE}, sorting of each MCMC draw conditional on the unconditional variance is done across homogeneous regime specification.\cr
 #' @references Andreas, S. (2012).
 #' \code{adaptMCMC}: Implementation of a generic adaptive Monte Carlo Markov chain sampler.
 #' \url{https://cran.r-project.org/package=adaptMCMC}
 #' @references Ardia, D. Bluteau, K. Boudt, K. Catania, L. & Trottier, D.-A. (2016).
 #' Markov-switching GARCH models in \R: The MSGARCH package.
 #' \url{https://ssrn.com/abstract=2845809}
+#' @references Geweke J (2007).
+#' Interpretation and Inference in Mixture Models: Simple MCMC Works.
+#' \emph{Computational Statistics & Data Analysis}, 51(7), 3529-3550.
 #' @references MacDonald, I.L., Zucchini, W. (1997).
 #' Hidden Markov and other models for discrete-valued time series.
 #' \emph{CRC press}.
@@ -83,21 +90,22 @@
 #'
 #' # fit the model on the data by MCMC
 #' set.seed(123)
-#' fit <- FitMCMC(spec = spec, data = SMI, ctr = list(n.burn = 500L, n.mcmc = 500L, n.thin = 1L))
+#' fit <- FitMCMC(spec = spec, data = SMI, ctr = list(nburn = 500L, nmcmc = 500L, nthin = 1L))
 #' summary(fit)
 #'
 #' # custom sampler example
 #' \dontrun{
 #' library("mcmc")
 #' f_MCMC <- function(f_posterior, data, spec, par0, ctr){
-#'   par <- mcmc::metrop(f_posterior, initial = par0, nbatch = ctr$n.mcmc + ctr$n.burn,
+#'   par <- mcmc::metrop(f_posterior, initial = par0, nbatch = ctr$nmcmc + ctr$nburn,
 #'                         data = data, spec = spec)$batch
+#'   colnames(par) = names(par0)
 #'   return(par)
 #' }
 #'
 #' set.seed(123)
 #' fit <- FitMCMC(spec, data = SMI, ctr  = list(SamplerFUN = f_MCMC,
-#'                                              n.burn = 500L, n.mcmc = 500L, n.thin = 1L))
+#'                                              nburn = 500L, nmcmc = 500L, nthin = 1L))
 #' summary(fit)
 #' }
 #' @import coda
@@ -112,7 +120,7 @@ FitMCMC.MSGARCH_SPEC <- function(spec, data, ctr = list()) {
 
   time.start <- Sys.time()
   spec <- f_check_spec(spec)
-  data <- f_check_y(data)
+  data_ <- f_check_y(data)
   ctr  <- f_process_ctr(ctr)
   ctr$do.plm <- TRUE
 
@@ -121,7 +129,7 @@ FitMCMC.MSGARCH_SPEC <- function(spec, data, ctr = list()) {
   }
 
   if (is.null(ctr$par0)) {
-    par0 <- f_StargingValues(data, spec, ctr)
+    par0 <- f_StargingValues(data_, spec, ctr)
   } else {
     par0 = ctr$par0
     if (isTRUE(spec$regime.const.pars.bool)) {
@@ -132,10 +140,10 @@ FitMCMC.MSGARCH_SPEC <- function(spec, data, ctr = list()) {
     }
     par0 <- f_unmapPar(par0, spec, do.plm = TRUE)
   }
-  par    <- ctr$SamplerFUN(f_posterior = f_posterior, data = data, spec = spec, par0 = par0, ctr = ctr)
+  par    <- ctr$SamplerFUN(f_posterior = f_posterior, data = data_, spec = spec, par0 = par0, ctr = ctr)
   np     <- length(par0)
   accept <- 1 - mean(duplicated(par))
-  by     <- seq(from = (ctr$n.burn + 1L), to = (ctr$n.burn + ctr$n.mcmc), by = ctr$n.thin)
+  by     <- seq(from = (ctr$nburn + 1L), to = (ctr$nburn + ctr$nmcmc), by = ctr$nthin)
 
   par    <- par[by, , drop = FALSE]
   vLower <- spec$lower
@@ -176,8 +184,9 @@ FitMCMC.MSGARCH_SPEC <- function(spec, data, ctr = list()) {
       par <- f_add_regimeconstpar_matrix(par, spec$K, spec$label)
     }
   }
-
-  par <- f_sort_par(spec, par)
+  if(isTRUE(ctr$do.sort)){
+    par <- f_sort_par(spec, par)
+  }
   par <- coda::mcmc(par)
   ctr$par0 <- par0
   elapsed.time <- Sys.time() - time.start
