@@ -35,15 +35,15 @@
 #'        }
 #' The \code{MSGARCH_ML_FIT} with the following methods:
 #' \itemize{
-#' \item \code{\link{AIC}}: Compute Akaike information criterion (AIC).
-#' \item \code{\link{BIC}}: Compute Bayesian information criterion (BIC).
+#' \item \code{AIC}: Compute Akaike information criterion (AIC).
+#' \item \code{BIC}: Compute Bayesian information criterion (BIC).
 #' \item \code{\link{Volatility}}: In-sample conditional volatility filterting of the overall process.
-#' \item \code{\link{Forecast}}: Forecast of the conditional volatility of the overall process.
+#' \item \code{predict}: Forecast of the conditional volatility of the overall process.
 #' \item \code{\link{UncVol}}: Unconditional volatility in each regime and the overall process.
-#' \item \code{\link{Pred}}: Predictive method.
+#' \item \code{\link{PredPdf}}: Predictive method.
 #' \item \code{\link{PIT}}: Probability Integral Transform.
 #' \item \code{\link{Risk}}: Value-at-Risk and Expected-Shortfall methods.
-#' \item \code{\link{Sim}}: Simulation method.
+#' \item \code{simulate}: Simulation method.
 #' \item \code{\link{State}}: State probabilities methods.
 #' \item \code{\link{ExtractStateFit}}: Single-regime model extractor.
 #' \item \code{summary}: Summary of the fit.
@@ -100,7 +100,7 @@ FitML.MSGARCH_SPEC <- function(spec, data, ctr = list()) {
   
   time.start <- Sys.time()
   spec <- f_check_spec(spec)
-  data <- f_check_y(data)
+  data_ <- f_check_y(data)
   ctr  <- f_process_ctr(ctr)
   
   if ((isTRUE(spec$fixed.pars.bool)) || (isTRUE(spec$regime.const.pars.bool))) {
@@ -109,7 +109,7 @@ FitML.MSGARCH_SPEC <- function(spec, data, ctr = list()) {
   }
   
   if (is.null(ctr$par0)) {
-    vPw  <- f_StargingValues(data, spec, ctr)
+    vPw  <- f_StargingValues(data_, spec, ctr)
     par0 <- matrix(f_mapPar(vPw, spec, ctr$do.plm), nrow = 1L, dimnames = list(NULL, names(vPw)))
   } else {
     par0 = ctr$par0
@@ -121,7 +121,7 @@ FitML.MSGARCH_SPEC <- function(spec, data, ctr = list()) {
       vPw <- f_substitute_fixedpar(vPw, spec$fixed.pars)
     }
   }
-  optimizer <- ctr$OptimFUN(vPw, f_nll, spec, data, ctr$do.plm)
+  optimizer <- ctr$OptimFUN(vPw, f_nll, spec, data_, ctr$do.plm)
   
   llk <- -optimizer$value
   
@@ -160,7 +160,7 @@ FitML.MSGARCH_SPEC <- function(spec, data, ctr = list()) {
   elapsed.time <- Sys.time() - time.start
   
   if (isTRUE(ctr$do.se)) {
-    Inference <- f_InferenceFun(vPww, data, spec, do.plm = ctr$do.plm)
+    Inference <- f_InferenceFun(vPww, data_, spec, do.plm = ctr$do.plm)
   } else {
     Inference <- NULL
   }
